@@ -26,7 +26,9 @@ from labml_helpers.module import Module
 
 class PrepareForMultiHeadAttention(Module):
     """
+    <a id="PrepareMHA">
     ## Prepare for multi-head attention
+    </a>
 
     This module does a linear transformation and splits the vector into given
     number of heads for multi-head attention.
@@ -60,7 +62,9 @@ class PrepareForMultiHeadAttention(Module):
 
 class MultiHeadAttention(Module):
     r"""
+    <a id="MHA">
     ## Multi-Head Attention Module
+    </a>
 
     This computes scaled multi-headed attention for given `query`, `key` and `value` vectors.
 
@@ -91,8 +95,8 @@ class MultiHeadAttention(Module):
         self.heads = heads
 
         # These transform the `query`, `key` and `value` vectors for multi-headed attention.
-        self.query = PrepareForMultiHeadAttention(d_model, heads, self.d_k,  bias=bias)
-        self.key = PrepareForMultiHeadAttention(d_model, heads, self.d_k,  bias=bias)
+        self.query = PrepareForMultiHeadAttention(d_model, heads, self.d_k, bias=bias)
+        self.key = PrepareForMultiHeadAttention(d_model, heads, self.d_k, bias=bias)
         self.value = PrepareForMultiHeadAttention(d_model, heads, self.d_k, bias=True)
 
         # Softmax for attention along the time dimension of `key`
@@ -119,10 +123,10 @@ class MultiHeadAttention(Module):
         return torch.einsum('ibhd,jbhd->ijbh', query, key)
 
     def forward(self, *,
-                 query: torch.Tensor,
-                 key: torch.Tensor,
-                 value: torch.Tensor,
-                 mask: Optional[torch.Tensor] = None):
+                query: torch.Tensor,
+                key: torch.Tensor,
+                value: torch.Tensor,
+                mask: Optional[torch.Tensor] = None):
         """
         `query`, `key` and `value` are the tensors that store
         collection of *query*, *key* and *value* vectors.
